package com.fs.course.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.course.mapper.FsUserCourseTrainingCampMapper;
import com.fs.course.domain.FsUserCourseTrainingCamp;
import com.fs.course.service.IFsUserCourseTrainingCampService;

/**
 * 会员训练营Service业务层处理
 *
 * @author fs
 * @date 2025-04-15
 */
@Service
public class FsUserCourseTrainingCampServiceImpl implements IFsUserCourseTrainingCampService
{
    @Autowired
    private FsUserCourseTrainingCampMapper fsUserCourseTrainingCampMapper;

    /**
     * 查询会员训练营
     *
     * @param trainingCampId 会员训练营ID
     * @return 会员训练营
     */
    @Override
    public FsUserCourseTrainingCamp selectFsUserCourseTrainingCampById(Long trainingCampId)
    {
        return fsUserCourseTrainingCampMapper.selectFsUserCourseTrainingCampById(trainingCampId);
    }

    /**
     * 查询会员训练营列表
     *
     * @param fsUserCourseTrainingCamp 会员训练营
     * @return 会员训练营
     */
    @Override
    public List<FsUserCourseTrainingCamp> selectFsUserCourseTrainingCampList(FsUserCourseTrainingCamp fsUserCourseTrainingCamp)
    {
        return fsUserCourseTrainingCampMapper.selectFsUserCourseTrainingCampList(fsUserCourseTrainingCamp);
    }

    /**
     * 新增会员训练营
     *
     * @param fsUserCourseTrainingCamp 会员训练营
     * @return 结果
     */
    @Override
    public int insertFsUserCourseTrainingCamp(FsUserCourseTrainingCamp fsUserCourseTrainingCamp)
    {
        fsUserCourseTrainingCamp.setCreateTime(DateUtils.getNowDate());
        return fsUserCourseTrainingCampMapper.insertFsUserCourseTrainingCamp(fsUserCourseTrainingCamp);
    }

    /**
     * 修改会员训练营
     *
     * @param fsUserCourseTrainingCamp 会员训练营
     * @return 结果
     */
    @Override
    public int updateFsUserCourseTrainingCamp(FsUserCourseTrainingCamp fsUserCourseTrainingCamp)
    {
        return fsUserCourseTrainingCampMapper.updateFsUserCourseTrainingCamp(fsUserCourseTrainingCamp);
    }

    /**
     * 批量删除会员训练营
     *
     * @param trainingCampIds 需要删除的会员训练营ID
     * @return 结果
     */
    @Override
    public int deleteFsUserCourseTrainingCampByIds(Long[] trainingCampIds)
    {
        return fsUserCourseTrainingCampMapper.deleteFsUserCourseTrainingCampByIds(trainingCampIds);
    }

    /**
     * 删除会员训练营信息
     *
     * @param trainingCampId 会员训练营ID
     * @return 结果
     */
    @Override
    public int deleteFsUserCourseTrainingCampById(Long trainingCampId)
    {
        return fsUserCourseTrainingCampMapper.deleteFsUserCourseTrainingCampById(trainingCampId);
    }
}
